@@ -59,8 +59,8 @@ from xlal.datatypes.ligotimegps import *
 from xlal.datatypes.real8fftplan import *
 from xlal.datatypes.real8frequencyseries import *
 from xlal.datatypes.real8timeseries import *
-from xlal.datatypes.simburst import SimBurst # don't import from_buffer() (yet?)
-from xlal.datatypes.siminspiraltable import SimInspiralTable # don't import from_buffer() (yet?)
-from xlal.datatypes.snglburst import SnglBurst # don't import from_buffer() (yet?)
-from xlal.datatypes.snglinspiraltable import SnglInspiralTable # don't import from_buffer() (yet?)
+from xlal.datatypes.simburst import *
+from xlal.datatypes.siminspiraltable import *
+from xlal.datatypes.snglburst import *
+from xlal.datatypes.snglinspiraltable import *
 from xlal.datatypes.snglringdowntable import *
