@@ -1,7 +1,7 @@
-id = "359a04aa520841cc8a4d9ef28fedb8642d58abd0"
-date = "2015-07-23 23:40:23 +0000"
+id = "fff074c3c0773879d2ccd8bed1043152668944a5"
+date = "2015-09-17 17:32:00 +0000"
 branch = "master"
-tag = "pylal-v0.8.0-v1"
+tag = "None"
 if tag == "None":
     tag = None
 author = "Kipp Cannon <kipp.cannon@ligo.org>"
@@ -10,11 +10,11 @@ committer = "Kipp Cannon <kipp.cannon@ligo.org>"
 status = "CLEAN: All modifications committed"
 version = id
 verbose_msg = """Branch: master
-Tag: pylal-v0.8.0-v1
-Id: 359a04aa520841cc8a4d9ef28fedb8642d58abd0
+Tag: None
+Id: fff074c3c0773879d2ccd8bed1043152668944a5
 
 Builder: Kipp Cannon <kipp.cannon@ligo.org>
-Build date: 2015-07-23 23:41:54 +0000
+Build date: 2015-09-17 17:32:48 +0000
 Repository status: CLEAN: All modifications committed"""
 
 import warnings
@@ -33,9 +33,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError, onmismatch + " is an unrecognized value of onmismatch"
-    if foreign_id == "359a04aa520841cc8a4d9ef28fedb8642d58abd0":
+    if foreign_id == "fff074c3c0773879d2ccd8bed1043152668944a5":
         return
-    msg = "Program id (359a04aa520841cc8a4d9ef28fedb8642d58abd0) does not match given id (%s)." % foreign_id
+    msg = "Program id (fff074c3c0773879d2ccd8bed1043152668944a5) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError, msg
 
