@@ -434,7 +434,7 @@ def sim_to_distance_effective_spin_parameter_bins_function(sim):
 		chi2 = sim.spin2z
 		chi = SimInspiralTaylorF2ReducedSpinComputeChi(sim.mass1, sim.mass2, chi1, chi2)
 
-	elif sim.waveform.startswith("IMRPhenomB") or sim.waveform.startswith("IMRPhenomC"):
+	elif sim.waveform.startswith("IMRPhenomB") or sim.waveform.startswith("IMRPhenomC") or sim.waveform.startswith("SEOBNR"):
 		chi = SimIMRPhenomBComputeChi(sim.mass1, sim.mass2, sim.spin1z, sim.spin2z)
 
 	else:
@@ -492,7 +492,6 @@ class DataBaseSummary(object):
 				print >> sys.stderr, "Gathering stats from: %s...." % (f,)
 			working_filename = dbtables.get_connection_filename(f, tmp_path = tmp_path, verbose = verbose)
 			connection = sqlite3.connect(working_filename)
-			dbtables.DBTable_set_connection(connection)
 			xmldoc = dbtables.get_xml(connection)
 
 			sim = False
@@ -543,18 +542,19 @@ class DataBaseSummary(object):
 					segments_to_consider_for_these_injections = self.this_injection_segments.intersection(instruments_set) - self.this_injection_segments.union(set(self.this_injection_segments.keys()) - instruments_set)
 					found, total, missed = get_min_far_inspiral_injections(connection, segments = segments_to_consider_for_these_injections, table_name = self.table_name)
 					if verbose:
-						print >> sys.stderr, "Total injections: %d; Found injections %d: Missed injections %d" % (len(total), len(found), len(missed))
+						print >> sys.stderr, "%s total injections: %d; Found injections %d: Missed injections %d" % (instruments, len(total), len(found), len(missed))
 					self.found_injections_by_instrument_set.setdefault(instruments_set, []).extend(found)
 					self.total_injections_by_instrument_set.setdefault(instruments_set, []).extend(total)
 					self.missed_injections_by_instrument_set.setdefault(instruments_set, []).extend(missed)
 
 			# All done
 			dbtables.discard_connection_filename(f, working_filename, verbose = verbose)
-			dbtables.DBTable_set_connection(None)
 		if len(self.numslides) > 1:
 			raise ValueError('number of slides differs between input files')
-		else:
+		elif self.numslides:
 			self.numslides = min(self.numslides)
+		else:
+			self.numslides = 0
 
 		# FIXME
 		# Things left to do
