@@ -1857,7 +1857,7 @@ def tophat_window2d(bins_x, bins_y):
 #
 
 
-def filter_array(a, window, cyclic = False):
+def filter_array(a, window, cyclic = False, use_fft = True):
 	"""
 	Filter an array using the window function.  The transformation is
 	done in place.  The data are assumed to be 0 outside of their
@@ -1870,6 +1870,15 @@ def filter_array(a, window, cyclic = False):
 	This is done silently;  to determine if window function truncation
 	will occur, check for yourself that your window function is smaller
 	than your data in all dimensions.
+
+	If use_fft is True, the window is convolved with the array using
+	FFT convolution.  This is done by processing the array in bands of
+	relatively small dynamic range each to work around numerical
+	dynamic range limitation in the FFTs, but the window function is
+	not treated similarly.  As a result the window is effectively
+	limited to a few orders of magnitude of dynamic range.  If use_fft
+	is False there are no dynamic range issues but the convolution can
+	be quite slow.
 	"""
 	assert not cyclic	# no longer supported, maybe in future
 	# check that the window and the data have the same number of
@@ -1892,43 +1901,46 @@ def filter_array(a, window, cyclic = False):
 			window_slices.append(slice(0, window.shape[d]))
 	window = window[window_slices]
 
-	# this loop works around dynamic range limits in the FFT
-	# convolution code.  we move data 4 orders of magnitude at a time
-	# from the original array into a work space, convolve the work
-	# space with the filter, zero the workspace in any elements that
-	# are more than 14 orders of magnitude below the maximum value in
-	# the result, and add the result to the total.
-	result = numpy.zeros_like(a)
-	while a.any():
-		# copy contents of input array to work space
-		workspace = numpy.copy(a)
+	if use_fft:
+		# this loop works around dynamic range limits in the FFT
+		# convolution code.  we move data 4 orders of magnitude at a time
+		# from the original array into a work space, convolve the work
+		# space with the filter, zero the workspace in any elements that
+		# are more than 14 orders of magnitude below the maximum value in
+		# the result, and add the result to the total.
+		result = numpy.zeros_like(a)
+		while a.any():
+			# copy contents of input array to work space
+			workspace = numpy.copy(a)
 
-		# mask = indexes of elements of work space not more than 4
-		# orders of magnitude larger than the smallest non-zero
-		# element.  these are the elements to be processed in this
-		# iteration
-		abs_workspace = abs(workspace)
-		mask = abs_workspace <= abs_workspace[abs_workspace > 0].min() * 1e4
-		del abs_workspace
+			# mask = indexes of elements of work space not more than 4
+			# orders of magnitude larger than the smallest non-zero
+			# element.  these are the elements to be processed in this
+			# iteration
+			abs_workspace = abs(workspace)
+			mask = abs_workspace <= abs_workspace[abs_workspace > 0].min() * 1e4
+			del abs_workspace
 
-		# zero the masked elements in the input array, zero
-		# everything except the masked elements in the work space
-		a[mask] = 0.
-		workspace[~mask] = 0.
-		del mask
+			# zero the masked elements in the input array, zero
+			# everything except the masked elements in the work space
+			a[mask] = 0.
+			workspace[~mask] = 0.
+			del mask
 
-		# convolve the work space with the kernel
-		workspace = signaltools.fftconvolve(workspace, window, mode = "same")
+			# convolve the work space with the kernel
+			workspace = signaltools.fftconvolve(workspace, window, mode = "same")
 
-		# determine the largest value in the work space, and set to
-		# zero anything more than 14 orders of magnitude smaller
-		abs_workspace = abs(workspace)
-		workspace[abs_workspace < abs_workspace.max() * 1e-14] = 0.
-		del abs_workspace
+			# determine the largest value in the work space, and set to
+			# zero anything more than 14 orders of magnitude smaller
+			abs_workspace = abs(workspace)
+			workspace[abs_workspace < abs_workspace.max() * 1e-14] = 0.
+			del abs_workspace
 
-		# sum what remains into the result
-		result += workspace
-		del workspace
+			# sum what remains into the result
+			result += workspace
+			del workspace
+	else:
+		result = signaltools.convolve(a, window, mode = "same")
 	# overwrite the input with the result
 	# FIXME:  in numpy >= 1.7.0 there is a copyto() function
 	a.flat = result.flat
